@@ -2,6 +2,7 @@ import json
 from typing import BinaryIO, Dict, Optional
 
 from mindee.document_config import DocumentConfig, DocumentConfigDict
+from mindee.documents.bank_check import BankCheck
 from mindee.documents.custom_document import CustomDocument
 from mindee.documents.financial_document import FinancialDocument
 from mindee.documents.invoice import Invoice
@@ -9,6 +10,7 @@ from mindee.documents.passport import Passport
 from mindee.documents.receipt import Receipt
 from mindee.endpoints import (
     OTS_OWNER,
+    BankCheckEndpoint,
     CustomEndpoint,
     HTTPException,
     InvoiceEndpoint,
@@ -247,6 +249,22 @@ class Client:
         self._doc_configs[(OTS_OWNER, "passport")] = config
         return self
 
+    def config_bank_check(self, api_key: Optional[str] = None) -> "Client":
+        """
+        Configure a Mindee Bank check document.
+
+        :param api_key: Bank check API key
+        """
+        config = DocumentConfig(
+            document_type="bank_check",
+            singular_name="bank_check",
+            plural_name="bank_checks",
+            constructor=BankCheck,
+            endpoints=[BankCheckEndpoint(api_key=api_key)],
+        )
+        self._doc_configs[(OTS_OWNER, "bank_check")] = config
+        return self
+
     def doc_from_path(
         self,
         input_path: str,
@@ -257,11 +275,11 @@ class Client:
         Load a document from an absolute path, as a string.
 
         :param input_path: Path of file to open
-        :param cut_pdf_mode: Number (between 1 and 3 incl.) of pages to reconstruct a pdf with.
+        :param cut_pdf_mode: Number (between 1 and 3 incl.) of pages to reconstruct a PDF with.
 
-            * if 1: pages [0]
-            * if 2: pages [0, n-2]
-            * if 3: pages [0, n-2, n-1]
+            * if 1: first page
+            * if 2: first page, penultimate page
+            * if 3: first page, penultimate page, last page
         :param cut_pdf: Automatically reconstruct a PDF with more than 4 pages
         """
         input_doc = PathDocument(input_path, cut_pdf=cut_pdf, n_pdf_pages=cut_pdf_mode)
@@ -281,11 +299,11 @@ class Client:
         Load a document from a normal Python file object/handle.
 
         :param input_file: Input file handle
-        :param cut_pdf_mode: Number (between 1 and 3 incl.) of pages to reconstruct a pdf with.
+        :param cut_pdf_mode: Number (between 1 and 3 incl.) of pages to reconstruct a PDF with.
 
-            * if 1: pages [0]
-            * if 2: pages [0, n-2]
-            * if 3: pages [0, n-2, n-1]
+            * if 1: first page
+            * if 2: first page, penultimate page
+            * if 3: first page, penultimate page, last page
         :param cut_pdf: Automatically reconstruct a PDF with more than 4 pages
         """
         input_doc = FileDocument(
@@ -311,11 +329,11 @@ class Client:
 
         :param input_string: Input to parse as base64 string
         :param filename: The name of the file (without the path)
-        :param cut_pdf_mode: Number (between 1 and 3 incl.) of pages to reconstruct a pdf with.
+        :param cut_pdf_mode: Number (between 1 and 3 incl.) of pages to reconstruct a PDF with.
 
-            * if 1: pages [0]
-            * if 2: pages [0, n-2]
-            * if 3: pages [0, n-2, n-1]
+            * if 1: first page
+            * if 2: first page, penultimate page
+            * if 3: first page, penultimate page, last page
         :param cut_pdf: Automatically reconstruct a PDF with more than 4 pages
         """
         input_doc = Base64Document(
@@ -344,9 +362,9 @@ class Client:
         :param filename: The name of the file (without the path)
         :param cut_pdf_mode: Number (between 1 and 3 incl.) of pages to reconstruct a PDF with.
 
-            * if 1: pages [0]
-            * if 2: pages [0, n-2]
-            * if 3: pages [0, n-2, n-1]
+            * if 1: first page
+            * if 2: first page, penultimate page
+            * if 3: first page, penultimate page, last page
         :param cut_pdf: Automatically reconstruct a PDF with more than 4 pages
         """
         input_doc = BytesDocument(
