@@ -1,11 +1,13 @@
 import datetime
-from typing import List, Optional, Type
+from typing import Any, Dict, List, Optional, Type
 
-# from mindee.inputs import InputDocument
-from mindee.http import Endpoint
+from mindee.endpoints import Endpoint
+from mindee.inputs import InputDocument
+
+TypeApiPrediction = Dict[str, Any]
 
 
-def serialize_for_json(obj):
+def serialize_for_json(obj: Any) -> Any:
     """
     Custom serializer for Document objects.
 
@@ -30,9 +32,9 @@ class Document:
 
     def __init__(
         self,
-        input_file,
+        input_file: InputDocument,
         document_type: str,
-        api_prediction: dict,
+        api_prediction: TypeApiPrediction,
         page_n: Optional[int] = None,
     ):
         if input_file:
@@ -49,7 +51,7 @@ class Document:
     @staticmethod
     def request(
         endpoints: List[Endpoint],
-        input_file,
+        input_file: InputDocument,
         include_words: bool = False,
         close_file: bool = True,
     ):
@@ -64,8 +66,8 @@ class Document:
         return endpoints[0].predict_request(input_file, include_words, close_file)
 
     def _build_from_api_prediction(
-        self, api_prediction: dict, page_n: Optional[int] = None
-    ):
+        self, api_prediction: TypeApiPrediction, page_n: Optional[int] = None
+    ) -> None:
         """Build the document from an API response JSON."""
         raise NotImplementedError()
 
