@@ -1,4 +1,4 @@
-from mindee.fields.base import Field
+from mindee.fields.base import Field, Optional
 
 
 class Orientation(Field):
@@ -10,7 +10,7 @@ class Orientation(Field):
         orientation_prediction: dict,
         value_key: str = "degrees",
         reconstructed: bool = False,
-        page_n=None,
+        page_n: Optional[int] = None,
     ):
         """
         Page orientation.
@@ -18,7 +18,7 @@ class Orientation(Field):
         :param orientation_prediction: Orientation prediction object from HTTP response
         :param value_key: Key to use in the orientation_prediction dict
         :param reconstructed: Bool for reconstructed object (not extracted in the API)
-        :param page_n: Page number for multi pages pdf
+        :param page_n: Page number for multi-page PDF
         """
         super().__init__(
             orientation_prediction,
