@@ -51,11 +51,8 @@ class InputDocument:
         if self.file_mimetype == "application/pdf":
             self.check_pdf_open()
             count_pages = self.count_pdf_pages()
-            if cut_pdf is True:
-                if count_pages > MAX_DOC_PAGES:
-                    self.merge_pdf_pages(
-                        [0, count_pages - 2, count_pages - 1][:n_pdf_pages]
-                    )
+            if cut_pdf is True and count_pages > 3:
+                self.merge_pdf_pages([0, -2, -1][:n_pdf_pages])
             if self.is_pdf_empty():
                 raise AssertionError(f"PDF pages are empty in: {self.filename}")
         logger.debug("Loaded new document '%s' from %s", self.filename, self.input_type)
